Read contents of .gz file(s) into a single character().

read_gz_file(file_paths)

Arguments

file_paths

File path from which to read.

Value

character()

Details

If more than one file path is provided, each elemente of the returned vector contains the contents of a single file.