character()
R/RcppExports.R
read_gz_file.Rd
Read contents of .gz file(s) into a single character().
read_gz_file(file_paths)
File path from which to read.
If more than one file path is provided, each elemente of the returned vector contains the contents of a single file.
Brendan Knapp brendan.g.knapp@gmail.com